@@ -1,11 +1,11 @@
 
 class BaseModelHook(object):
     @classmethod
-    def on_hook_register(cls, model_class):
+    def on_hook_register(cls, model_class, *args, **kwargs):
         pass
 
     @classmethod
-    def on_hook_unregister(cls, model_class):
+    def on_hook_unregister(cls, model_class, *args, **kwargs):
         pass
 
     @classmethod
